=======
Insegel
=======

.. image:: https://scieldas.autophagy.io/github/workflow/status/autophagy/insegel/Build.png
    :target: https://github.com/autophagy/insegel/actions/workflows/build.yaml
    :alt: Build Status

.. image:: https://scieldas.autophagy.io/rtd/build/insegel.png
    :target: http://insegel.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://scieldas.autophagy.io/pypi/version/insegel.png
   :target: https://pypi.python.org/pypi/insegel/
   :alt: Pypi Version

.. image:: https://scieldas.autophagy.io/pypi/pyversions/insegel.png
   :target: https://pypi.python.org/pypi/insegel/
   :alt: Python Version

.. image:: https://scieldas.autophagy.io/misc/licenses/mit.png
   :target: LICENSE
   :alt: MIT License

Insegel is a theme for `Sphinx`_, intended to unify my project documentation's
theme with that of `Hrǽw`_. The theme's documentation is available on
`ReadTheDocs`_.

.. image:: docs/_static/screenshot.png
    :alt: aerende
    :align: center

Installation
============

To use the Insegel theme, install it via pip::

   pip install insegel

Or, you can add it to your Sphinx project's requirements files.
You can then set Sphinx to use the theme via::

   html_theme = 'insegel'

within your documentation's ``conf.py`` file.


.. _Sphinx: http://www.sphinx-doc.org/en/stable/
.. _Hrǽw: https://github.com/Autophagy/hraew
.. _ReadTheDocs: http://insegel.readthedocs.io
